@@ -6,6 +6,8 @@
 import cairo
 import math
 import numpy as np
+
+import generativepy.geometry
 from generativepy.color import Color
 from generativepy import drawing
 
@@ -38,14 +40,14 @@ class Axes:
         for p in self.get_divs(self.start[0], self.extent[0], self.divisions[0]):
            if abs(p)>0.001:
                 pstr = self.format_div(p, self.divisions[0])
-                drawing.text(self.ctx, pstr, p - xoffset, -yoffset, alignx=drawing.RIGHT, aligny=drawing.TOP, flip=True)
+                generativepy.geometry.text(self.ctx, pstr, p - xoffset, -yoffset, alignx=drawing.RIGHT, aligny=drawing.TOP, flip=True)
 
         xoffset = self.pts2pixels(1)
         yoffset = self.pts2pixels(1)
         for p in self.get_divs(self.start[1], self.extent[1], self.divisions[1]):
            if abs(p)>0.001:
                 pstr = self.format_div(p, self.divisions[0])
-                drawing.text(self.ctx, pstr, -xoffset, p - yoffset, alignx=drawing.RIGHT, aligny=drawing.TOP, flip=True)
+                generativepy.geometry.text(self.ctx, pstr, -xoffset, p - yoffset, alignx=drawing.RIGHT, aligny=drawing.TOP, flip=True)
 
         self.ctx.set_line_width(self.pts2pixels(0.5))
         self.ctx.new_path()
@@ -110,7 +112,7 @@ def plot_curve(axes, fn, line_color=Color(1, 0, 0), extent=None, line_width=.7):
         ctx.set_line_width(axes.pts2pixels(line_width))
         ctx.set_source_rgba(*line_color)
 
-        drawing.polygon(ctx, points, False)
+        generativepy.geometry.polygon(ctx, points, False)
         ctx.stroke()
         axes.unclip()
 
@@ -135,7 +137,7 @@ def plot_xy_curve(axes, fn, line_color=Color(1, 0, 0), extent=None, line_width=.
         ctx.set_line_width(axes.pts2pixels(line_width))
         ctx.set_source_rgba(*line_color)
 
-        drawing.polygon(ctx, points, False)
+        generativepy.geometry.polygon(ctx, points, False)
         ctx.stroke()
         axes.unclip()
 
@@ -160,56 +162,6 @@ def plot_polar_curve(axes, fn, line_color=Color(1, 0, 0), extent=(0, 2*math.pi),
         ctx.set_line_width(axes.pts2pixels(line_width))
         ctx.set_source_rgba(*line_color)
 
-        drawing.polygon(ctx, points, False)
+        generativepy.geometry.polygon(ctx, points, False)
         ctx.stroke()
         axes.unclip()
-
-#
-# 
-# def plotYXCurve(axes, fn, lineColor=Color(1, 0, 0), extent=None, line_width=.7):
-#     """
-#     Plot an x = fn(y)
-#     :param mctx: maths context
-#     :param fn: the function, a function object taking 1 number and returning a number
-#     :param lineColor: color of line (r, g, b) each channel in range 0.0 to 1.0
-#     :param extent: tuple (start, end) giving extent of curve, or None for the curve to fill the y range
-#     :param line_width: line width in page space
-#     :return:
-#     """
-#     canvas = axes.canvas
-#     points = []
-#     for y in np.linspace(axes.start[1], axes.start[1]+axes.extent[1], 100):
-#         if not extent or extent[0] <= y <= extent[1]:
-#             points.append((fn(y), y))
-#     if points:
-#         axes.clip()
-#         canvas.stroke(lineColor)
-#         canvas.noFill()
-#         canvas.strokeWeight(canvas.page2user(line_width))
-#         canvas.polygon(points, False)
-#         axes.unclip()
-# 
-# 
-# def plotPolarCurve(axes, fn, lineColor=drawing.Color(1, 0, 0), extent=(0, 2*math.pi), line_width=.7):
-#     """
-#     Plot an r = fn(theta)
-#     :param mctx: maths context
-#     :param fn: the function, a function object taking 1 number and returning a number
-#     :param lineColor: color of line (r, g, b) each channel in range 0.0 to 1.0
-#     :param extent: tuple (start, end) giving extent of curve, or None for the curve to fill the y range
-#     :param line_width: line width in page space
-#     :return:
-#     """
-#     canvas = axes.canvas
-#     points = []
-#     for theta in np.linspace(range[0], range[1], 100):
-#         if not extent or extent[0] <= theta <= extent[1]:
-#             r = fn(theta)
-#             points.append((r*math.cos(theta), r*math.sin(theta)))
-#     if points:
-#         axes.clip()
-#         canvas.stroke(lineColor)
-#         canvas.noFill()
-#         canvas.strokeWeight(canvas.page2user(line_width))
-#         canvas.polygon(points, False)
-#         axes.unclip()
